@@ -8,6 +8,8 @@ import (
 	"strings"
 	"time"
 
+	"github.com/weaveworks/eksctl/pkg/awsapi"
+
 	"github.com/aws/aws-sdk-go/service/cloudwatchlogs/cloudwatchlogsiface"
 
 	"github.com/aws/aws-sdk-go/aws/client"
@@ -666,6 +668,8 @@ type ClusterProvider interface {
 	WaitTimeout() time.Duration
 	ConfigProvider() client.ConfigProvider
 	Session() *session.Session
+
+	STSV2() awsapi.STS
 }
 
 // ProviderConfig holds global parameters for all interactions with AWS APIs
@@ -988,6 +992,10 @@ type NodeGroup struct {
 	// +optional
 	ContainerRuntime *string `json:"containerRuntime,omitempty"`
 
+	// Propagate all taints and labels to the ASG automatically.
+	// +optional
+	PropagateASGTags *bool `json:"propagateASGTags,omitempty"`
+
 	// DisableASGTagPropagation disable the tag propagation in case desired capacity is 0.
 	// +optional
 	DisableASGTagPropagation *bool `json:"disableASGTagPropagation,omitempty"`
