@@ -88,6 +88,10 @@ var _ = Describe("create nodegroup", func() {
 				args:  []string{"--cluster", "clusterName", "--name", "eksctl-ng_k8s_nodegroup1"},
 				error: "validation for eksctl-ng_k8s_nodegroup1 failed, name must satisfy regular expression pattern: [a-zA-Z][-a-zA-Z0-9]*",
 			}),
+			Entry("with enableSsm disabled", invalidParamsCase{
+				args:  []string{"--cluster=test", "--enable-ssm=false"},
+				error: "SSM agent is now built into EKS AMIs and cannot be disabled",
+			}),
 		)
 	})
 
