@@ -15,22 +15,25 @@ import (
 )
 
 func deleteClusterCmd(cmd *cmdutils.Cmd) {
-	deleteClusterWithRunFunc(cmd, func(cmd *cmdutils.Cmd, force bool, disableNodegroupEviction bool) error {
-		return doDeleteCluster(cmd, force, disableNodegroupEviction)
+	deleteClusterWithRunFunc(cmd, func(cmd *cmdutils.Cmd, force bool, disableNodegroupEviction bool, parallel int) error {
+		return doDeleteCluster(cmd, force, disableNodegroupEviction, parallel)
 	})
 }
 
-func deleteClusterWithRunFunc(cmd *cmdutils.Cmd, runFunc func(cmd *cmdutils.Cmd, force bool, disableNodegroupEviction bool) error) {
+func deleteClusterWithRunFunc(cmd *cmdutils.Cmd, runFunc func(cmd *cmdutils.Cmd, force bool, disableNodegroupEviction bool, parallel int) error) {
 	cfg := api.NewClusterConfig()
 	cmd.ClusterConfig = cfg
 
 	cmd.SetDescription("cluster", "Delete a cluster", "")
 
-	var force bool
-	var disableNodegroupEviction bool
+	var (
+		force                    bool
+		disableNodegroupEviction bool
+		parallel                 int
+	)
 	cmd.CobraCommand.RunE = func(_ *cobra.Command, args []string) error {
 		cmd.NameArg = cmdutils.GetNameArg(args)
-		return runFunc(cmd, force, disableNodegroupEviction)
+		return runFunc(cmd, force, disableNodegroupEviction, parallel)
 	}
 
 	cmd.FlagSetGroup.InFlagSet("General", func(fs *pflag.FlagSet) {
@@ -41,6 +44,7 @@ func deleteClusterWithRunFunc(cmd *cmdutils.Cmd, runFunc func(cmd *cmdutils.Cmd,
 		cmdutils.AddWaitFlag(fs, &cmd.Wait, "deletion of all resources")
 		fs.BoolVar(&force, "force", false, "Force deletion to continue when errors occur")
 		fs.BoolVar(&disableNodegroupEviction, "disable-nodegroup-eviction", false, "Force drain to use delete, even if eviction is supported. This will bypass checking PodDisruptionBudgets, use with caution.")
+		fs.IntVar(&parallel, "parallel", 1, "Number of nodes to drain in parallel. Max 25")
 
 		cmdutils.AddConfigFileFlag(fs, &cmd.ClusterConfigFile)
 		cmdutils.AddTimeoutFlag(fs, &cmd.ProviderConfig.WaitTimeout)
@@ -49,7 +53,7 @@ func deleteClusterWithRunFunc(cmd *cmdutils.Cmd, runFunc func(cmd *cmdutils.Cmd,
 	cmdutils.AddCommonFlagsForAWS(cmd.FlagSetGroup, &cmd.ProviderConfig, true)
 }
 
-func doDeleteCluster(cmd *cmdutils.Cmd, force bool, disableNodegroupEviction bool) error {
+func doDeleteCluster(cmd *cmdutils.Cmd, force bool, disableNodegroupEviction bool, parallel int) error {
 	if err := cmdutils.NewMetadataLoader(cmd).Load(); err != nil {
 		return err
 	}
@@ -81,5 +85,5 @@ func doDeleteCluster(cmd *cmdutils.Cmd, force bool, disableNodegroupEviction boo
 		return err
 	}
 
-	return cluster.Delete(time.Second*20, cmd.Wait, force, disableNodegroupEviction)
+	return cluster.Delete(time.Second*20, cmd.Wait, force, disableNodegroupEviction, parallel)
 }
