@@ -6,7 +6,6 @@ import (
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/ginkgo/extensions/table"
 	. "github.com/onsi/gomega"
-	"github.com/pkg/errors"
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -35,8 +34,7 @@ var _ = Describe("NodeGroup", func() {
 
 			version, err := GetNodegroupKubernetesVersion(fakeClientSet.CoreV1().Nodes(), ngName)
 
-			if t.expectedVersion == "" {
-				Expect(err).To(HaveOccurred())
+			if t.expError != nil {
 				Expect(err).To(MatchError(ContainSubstring(t.expError.Error())))
 				return
 			}
@@ -85,7 +83,7 @@ var _ = Describe("NodeGroup", func() {
 				expectedVersion: "1.19.6",
 			}),
 
-			Entry("fails to list nodes", ngEntry{
+			Entry("fails to list nodes returns empty version", ngEntry{
 				mockCalls: func(c *fake.Clientset) {
 					_, err := c.CoreV1().Nodes().Create(context.TODO(), &v1.Node{
 						ObjectMeta: metav1.ObjectMeta{
@@ -94,7 +92,7 @@ var _ = Describe("NodeGroup", func() {
 					}, metav1.CreateOptions{})
 					Expect(err).NotTo(HaveOccurred())
 				},
-				expError: errors.New("no nodes were found"),
+				expectedVersion: "",
 			}),
 		)
 	})
